build status fails sometimes - selenium and iframes and ... sleep. Passes with local tox, believe me.

.. image:: https://github.com/bnzk/django-ckeditor-link/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/bnzk/django-ckeditor-link/actions/workflows/ci.yml
.. image:: https://img.shields.io/pypi/v/django-ckeditor-link.svg
    :target: https://pypi.python.org/pypi/django-ckeditor-link/
.. image:: https://img.shields.io/pypi/l/django-ckeditor-link.svg
    :target: https://pypi.python.org/pypi/django-ckeditor-link/

link plugin for ckeditor, based on django modelforms/modeladmin, allowing direct linking to your models, or to whatever your want.

Development and Docs on `<https://github.com/bnzk/django-ckeditor-link/>`_